//   Copyright Naoki Shibata and contributors 2010 - 2023.
// Distributed under the Boost Software License, Version 1.0.
//    (See accompanying file LICENSE.txt or copy at
//          http://www.boost.org/LICENSE_1_0.txt)

#ifndef __SLEEF_H__
#define __SLEEF_H__

#define SLEEF_VERSION_MAJOR 3
#define SLEEF_VERSION_MINOR 6
#define SLEEF_VERSION_PATCHLEVEL 0

#include <stddef.h>
#include <stdint.h>

#if defined (__GNUC__) || defined (__clang__) || defined(__INTEL_COMPILER)
#define SLEEF_CONST __attribute__((const))
#define SLEEF_INLINE __attribute__((always_inline))
#elif defined(_MSC_VER)
#define SLEEF_CONST
#define SLEEF_INLINE __forceinline
#endif

#if defined(__AVX2__) || defined(__aarch64__) || defined(__arm__) || defined(__powerpc64__) || defined(__zarch__)
#ifndef FP_FAST_FMA
#define FP_FAST_FMA
#endif
#ifndef FP_FAST_FMAF
#define FP_FAST_FMAF
#endif
#endif

#if defined(_MSC_VER) && !defined(__STDC__)
#define __STDC__ 1
#endif

#if (defined(__MINGW32__) || defined(__MINGW64__) || defined(__CYGWIN__) || defined(_MSC_VER)) && !defined(SLEEF_STATIC_LIBS)
#ifdef SLEEF_IMPORT_IS_EXPORT
#define SLEEF_IMPORT __declspec(dllexport)
#else // #ifdef SLEEF_IMPORT_IS_EXPORT
#define SLEEF_IMPORT __declspec(dllimport)
#if (defined(_MSC_VER))
#pragma comment(lib,"sleef.lib")
#endif // #if (defined(_MSC_VER))
#endif // #ifdef SLEEF_IMPORT_IS_EXPORT
#else // #if (defined(__MINGW32__) || defined(__MINGW64__) || defined(__CYGWIN__) || defined(_MSC_VER)) && !defined(SLEEF_STATIC_LIBS)
#define SLEEF_IMPORT
#endif // #if (defined(__MINGW32__) || defined(__MINGW64__) || defined(__CYGWIN__) || defined(_MSC_VER)) && !defined(SLEEF_STATIC_LIBS)

#if (defined(__GNUC__) || defined(__CLANG__)) && (defined(__i386__) || defined(__x86_64__))
#include <x86intrin.h>
#endif

#if (defined(_MSC_VER))
#include <intrin.h>
#endif

#if defined(__ARM_NEON__) || defined(__ARM_NEON)
#include <arm_neon.h>
#endif

#if defined(__ARM_FEATURE_SVE)
#include <arm_sve.h>
#endif

#if defined(__VSX__) && defined(__PPC64__) && defined(__LITTLE_ENDIAN__)
#include <altivec.h>
typedef __vector double       SLEEF_VECTOR_DOUBLE;
typedef __vector float        SLEEF_VECTOR_FLOAT;
typedef __vector int          SLEEF_VECTOR_INT;
typedef __vector unsigned int SLEEF_VECTOR_UINT;
typedef __vector long long SLEEF_VECTOR_LONGLONG;
typedef __vector unsigned long long SLEEF_VECTOR_ULONGLONG;
#endif

#if defined(__VX__) && defined(__VEC__)
#ifndef SLEEF_VECINTRIN_H_INCLUDED
#include <vecintrin.h>
#define SLEEF_VECINTRIN_H_INCLUDED
#endif
typedef __vector double       SLEEF_VECTOR_DOUBLE;
typedef __vector float        SLEEF_VECTOR_FLOAT;
typedef __vector int          SLEEF_VECTOR_INT;
typedef __vector unsigned int SLEEF_VECTOR_UINT;
typedef __vector long long SLEEF_VECTOR_LONGLONG;
typedef __vector unsigned long long SLEEF_VECTOR_ULONGLONG;
#endif

//

#if defined(SLEEF_ENABLE_OMP_SIMD) && (defined(__GNUC__) || defined(__CLANG__)) && !defined(__INTEL_COMPILER)
#if defined(__aarch64__)
//#define SLEEF_PRAGMA_OMP_SIMD_DP _Pragma ("omp declare simd simdlen(2) notinbranch")
//#define SLEEF_PRAGMA_OMP_SIMD_SP _Pragma ("omp declare simd simdlen(4) notinbranch")
//#elif defined(__x86_64__) && defined(__AVX512F__)
//#define SLEEF_PRAGMA_OMP_SIMD_DP _Pragma ("omp declare simd simdlen(8) notinbranch")
//#define SLEEF_PRAGMA_OMP_SIMD_SP _Pragma ("omp declare simd simdlen(16) notinbranch")
#elif defined(__x86_64__) && defined(__AVX__)
#define SLEEF_PRAGMA_OMP_SIMD_DP _Pragma ("omp declare simd simdlen(4) notinbranch")
#define SLEEF_PRAGMA_OMP_SIMD_SP _Pragma ("omp declare simd simdlen(8) notinbranch")
#elif defined(__x86_64__) && defined(__SSE2__)
#define SLEEF_PRAGMA_OMP_SIMD_DP _Pragma ("omp declare simd simdlen(2) notinbranch")
#define SLEEF_PRAGMA_OMP_SIMD_SP _Pragma ("omp declare simd simdlen(4) notinbranch")
#endif
#endif

#ifndef SLEEF_PRAGMA_OMP_SIMD_DP
#define SLEEF_PRAGMA_OMP_SIMD_DP
#define SLEEF_PRAGMA_OMP_SIMD_SP
#endif

//

#ifndef SLEEF_FP_ILOGB0
#define SLEEF_FP_ILOGB0 ((int)0x80000000)
#endif

#ifndef SLEEF_FP_ILOGBNAN
#define SLEEF_FP_ILOGBNAN ((int)2147483647)
#endif

//

SLEEF_IMPORT void *Sleef_malloc(size_t z);
SLEEF_IMPORT void Sleef_free(void *ptr);
SLEEF_IMPORT uint64_t Sleef_currentTimeMicros();

#if defined(__i386__) || defined(__x86_64__) || defined(_MSC_VER)
SLEEF_IMPORT void Sleef_x86CpuID(int32_t out[4], uint32_t eax, uint32_t ecx);
#endif

//

#if defined(__riscv_v)
#include <riscv_vector.h>
typedef vfloat64m2_t Sleef_vfloat64m1_t_2;
typedef vfloat32m2_t Sleef_vfloat32m1_t_2;
typedef vfloat64m4_t Sleef_vfloat64m2_t_2;
typedef vfloat32m4_t Sleef_vfloat32m2_t_2;
#define Sleef_vfloat64m1_t_2_DEFINED
#define Sleef_vfloat32m1_t_2_DEFINED
#define Sleef_vfloat64m2_t_2_DEFINED
#define Sleef_vfloat32m2_t_2_DEFINED
#endif

#ifndef Sleef_double2_DEFINED
#define Sleef_double2_DEFINED
typedef struct {
  double x, y;
} Sleef_double2;
#endif

#ifndef Sleef_float2_DEFINED
#define Sleef_float2_DEFINED
typedef struct {
  float x, y;
} Sleef_float2;
#endif

#ifdef __cplusplus
extern "C"
{
#endif

SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sin_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_cos_u35(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double2 Sleef_sincos_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_tan_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_asin_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_acos_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_atan_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_atan2_u35(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_log_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_cbrt_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sin_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_cos_u10(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double2 Sleef_sincos_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_tan_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_asin_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_acos_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_atan_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_atan2_u10(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_log_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_cbrt_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_exp_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_pow_u10(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sinh_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_cosh_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_tanh_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sinh_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_cosh_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_tanh_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_asinh_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_acosh_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_atanh_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_exp2_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_exp10_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_exp2_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_exp10_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_expm1_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_log10_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_log2_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_log2_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_log1p_u10(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double2 Sleef_sincospi_u05(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double2 Sleef_sincospi_u35(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sinpi_u05(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_cospi_u05(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_ldexp(double, int);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST int Sleef_ilogb(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_fma(double, double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sqrt(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sqrt_u05(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_sqrt_u35(double);

SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_hypot_u05(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_hypot_u35(double, double);

SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_fabs(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_copysign(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_fmax(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_fmin(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_fdim(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_trunc(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_floor(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_ceil(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_round(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_rint(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_nextafter(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_frfrexp(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST int Sleef_expfrexp(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_fmod(double, double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_remainder(double, double);
SLEEF_IMPORT SLEEF_CONST Sleef_double2 Sleef_modf(double);

SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_lgamma_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_tgamma_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_erf_u10(double);
SLEEF_PRAGMA_OMP_SIMD_DP SLEEF_IMPORT SLEEF_CONST double Sleef_erfc_u15(double);

SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sinf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_cosf_u35(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float2 Sleef_sincosf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_tanf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_asinf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_acosf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_atanf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_atan2f_u35(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_logf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_cbrtf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sinf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_cosf_u10(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float2 Sleef_sincosf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fastsinf_u3500(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fastcosf_u3500(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_tanf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_asinf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_acosf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_atanf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_atan2f_u10(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_logf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_cbrtf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_expf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_powf_u10(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fastpowf_u3500(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sinhf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_coshf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_tanhf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sinhf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_coshf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_tanhf_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_asinhf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_acoshf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_atanhf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_exp2f_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_exp10f_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_exp2f_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_exp10f_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_expm1f_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_log10f_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_log2f_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_log2f_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_log1pf_u10(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float2 Sleef_sincospif_u05(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float2 Sleef_sincospif_u35(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sinpif_u05(float d);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_cospif_u05(float d);
SLEEF_IMPORT SLEEF_CONST float Sleef_ldexpf(float, int);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST int Sleef_ilogbf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fmaf(float, float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf_u05(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf_u35(float);

SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_hypotf_u05(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_hypotf_u35(float, float);

SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fabsf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_copysignf(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fmaxf(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fminf(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fdimf(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_truncf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_floorf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_ceilf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_roundf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_rintf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_nextafterf(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_frfrexpf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST int Sleef_expfrexpf(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_fmodf(float, float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_remainderf(float, float);
SLEEF_IMPORT SLEEF_CONST Sleef_float2 Sleef_modff(float);

SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_lgammaf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_tgammaf_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_erff_u10(float);
SLEEF_PRAGMA_OMP_SIMD_SP SLEEF_IMPORT SLEEF_CONST float Sleef_erfcf_u15(float);
#ifdef __riscv_v

#ifndef Sleef_vfloat64m1_t_2_DEFINED
typedef struct {
  vfloat64m1_t x, y;
} Sleef_vfloat64m1_t_2;
#define Sleef_vfloat64m1_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sindx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sindx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cosdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_cosdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincosdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_finz_sincosdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tandx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_tandx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_asindx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_asindx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_acosdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_acosdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atandx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_atandx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atan2dx_u35rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_atan2dx_u35rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_logdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_logdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cbrtdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_cbrtdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sindx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sindx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cosdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_cosdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincosdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_finz_sincosdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tandx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_tandx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_asindx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_asindx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_acosdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_acosdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atandx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_atandx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atan2dx_u10rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_atan2dx_u10rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_logdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_logdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cbrtdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_cbrtdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_expdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_expdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_powdx_u10rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_powdx_u10rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sinhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sinhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_coshdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_coshdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tanhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_tanhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sinhdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sinhdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_coshdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_coshdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tanhdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_tanhdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fastsindx_u3500rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fastsindx_u3500rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fastcosdx_u3500rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fastcosdx_u3500rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fastpowdx_u3500rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fastpowdx_u3500rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_asinhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_asinhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_acoshdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_acoshdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atanhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_atanhdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp2dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_exp2dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp2dx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_exp2dx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp10dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_exp10dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp10dx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_exp10dx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_expm1dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_expm1dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log10dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_log10dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log2dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_log2dx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log2dx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_log2dx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log1pdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_log1pdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincospidx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_finz_sincospidx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincospidx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_finz_sincospidx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sinpidx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sinpidx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cospidx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_cospidx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_ldexpdx_rvvm1(vfloat64m1_t, vint32mf2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_ldexpdx_rvvm1(vfloat64m1_t, vint32mf2_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_ilogbdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_finz_ilogbdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmadx_rvvm1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fmadx_rvvm1(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sqrtdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sqrtdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sqrtdx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sqrtdx_u05rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sqrtdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_sqrtdx_u35rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_hypotdx_u05rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_hypotdx_u05rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_hypotdx_u35rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_hypotdx_u35rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fabsdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fabsdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_copysigndx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_copysigndx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmaxdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fmaxdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmindx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fmindx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fdimdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fdimdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_truncdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_truncdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_floordx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_floordx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_ceildx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_ceildx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_rounddx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_rounddx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_rintdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_rintdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_nextafterdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_nextafterdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_frfrexpdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_frfrexpdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_expfrexpdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_finz_expfrexpdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmoddx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_fmoddx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_remainderdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_remainderdx_rvvm1(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_modfdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_finz_modfdx_rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_lgammadx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_lgammadx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tgammadx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_tgammadx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_erfdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_erfdx_u10rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_erfcdx_u15rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_finz_erfcdx_u15rvvm1(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntdx_rvvm1(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrdx_rvvm1(int);

#ifndef Sleef_vfloat32m1_t_2_DEFINED
typedef struct {
  vfloat32m1_t x, y;
} Sleef_vfloat32m1_t_2;
#define Sleef_vfloat32m1_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sinfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cosfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_cosfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincosfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_finz_sincosfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_tanfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_asinfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_asinfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_acosfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_acosfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atanfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_atanfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atan2fx_u35rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_atan2fx_u35rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_logfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_logfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cbrtfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_cbrtfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sinfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cosfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_cosfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincosfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_finz_sincosfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_tanfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_asinfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_asinfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_acosfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_acosfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atanfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_atanfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atan2fx_u10rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_atan2fx_u10rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_logfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_logfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cbrtfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_cbrtfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_expfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_expfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_powfx_u10rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_powfx_u10rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sinhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_coshfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_coshfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_tanhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinhfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sinhfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_coshfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_coshfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanhfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_tanhfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fastsinfx_u3500rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fastsinfx_u3500rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fastcosfx_u3500rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fastcosfx_u3500rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fastpowfx_u3500rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fastpowfx_u3500rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_asinhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_asinhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_acoshfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_acoshfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atanhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_atanhfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp2fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_exp2fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp2fx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_exp2fx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp10fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_exp10fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp10fx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_exp10fx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_expm1fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_expm1fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log10fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_log10fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log2fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_log2fx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log2fx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_log2fx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log1pfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_log1pfx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincospifx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_finz_sincospifx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincospifx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_finz_sincospifx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinpifx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sinpifx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cospifx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_cospifx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fmafx_rvvm1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fmafx_rvvm1(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sqrtfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sqrtfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sqrtfx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sqrtfx_u05rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sqrtfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_sqrtfx_u35rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_hypotfx_u05rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_hypotfx_u05rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_hypotfx_u35rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_hypotfx_u35rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fabsfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fabsfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_copysignfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_copysignfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fmaxfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fmaxfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fminfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fminfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fdimfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fdimfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_truncfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_truncfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_floorfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_floorfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_ceilfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_ceilfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_roundfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_roundfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_rintfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_rintfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_nextafterfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_nextafterfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_frfrexpfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_frfrexpfx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fmodfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_fmodfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_remainderfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_remainderfx_rvvm1(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_modffx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_finz_modffx_rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_lgammafx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_lgammafx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tgammafx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_tgammafx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_erffx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_erffx_u10rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_erfcfx_u15rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_finz_erfcfx_u15rvvm1(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntfx_rvvm1(int);
SLEEF_IMPORT SLEEF_CONST int Sleef_finz_getIntfx_rvvm1(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrfx_rvvm1(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_finz_getPtrfx_rvvm1(int);
#endif
#ifdef __riscv_v

#ifndef Sleef_vfloat64m1_t_2_DEFINED
typedef struct {
  vfloat64m1_t x, y;
} Sleef_vfloat64m1_t_2;
#define Sleef_vfloat64m1_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sindx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sindx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cosdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_cosdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincosdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_cinz_sincosdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tandx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_tandx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_asindx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_asindx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_acosdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_acosdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atandx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_atandx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atan2dx_u35rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_atan2dx_u35rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_logdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_logdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cbrtdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_cbrtdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sindx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sindx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cosdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_cosdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincosdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_cinz_sincosdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tandx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_tandx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_asindx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_asindx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_acosdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_acosdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atandx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_atandx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atan2dx_u10rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_atan2dx_u10rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_logdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_logdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cbrtdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_cbrtdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_expdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_expdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_powdx_u10rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_powdx_u10rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sinhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sinhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_coshdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_coshdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tanhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_tanhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sinhdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sinhdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_coshdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_coshdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tanhdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_tanhdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fastsindx_u3500rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fastsindx_u3500rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fastcosdx_u3500rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fastcosdx_u3500rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fastpowdx_u3500rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fastpowdx_u3500rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_asinhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_asinhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_acoshdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_acoshdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_atanhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_atanhdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp2dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_exp2dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp2dx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_exp2dx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp10dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_exp10dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_exp10dx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_exp10dx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_expm1dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_expm1dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log10dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_log10dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log2dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_log2dx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log2dx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_log2dx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_log1pdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_log1pdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincospidx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_cinz_sincospidx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_sincospidx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_cinz_sincospidx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sinpidx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sinpidx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cospidx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_cospidx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_ldexpdx_rvvm1nofma(vfloat64m1_t, vint32mf2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_ldexpdx_rvvm1nofma(vfloat64m1_t, vint32mf2_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_ilogbdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_cinz_ilogbdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmadx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fmadx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sqrtdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sqrtdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sqrtdx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sqrtdx_u05rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_sqrtdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_sqrtdx_u35rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_hypotdx_u05rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_hypotdx_u05rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_hypotdx_u35rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_hypotdx_u35rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fabsdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fabsdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_copysigndx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_copysigndx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmaxdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fmaxdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmindx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fmindx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fdimdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fdimdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_truncdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_truncdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_floordx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_floordx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_ceildx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_ceildx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_rounddx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_rounddx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_rintdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_rintdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_nextafterdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_nextafterdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_frfrexpdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_frfrexpdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_expfrexpdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vint32mf2_t Sleef_cinz_expfrexpdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_fmoddx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_fmoddx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_remainderdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_remainderdx_rvvm1nofma(vfloat64m1_t, vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_modfdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m1_t_2 Sleef_cinz_modfdx_rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_lgammadx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_lgammadx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_tgammadx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_tgammadx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_erfdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_erfdx_u10rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_erfcdx_u15rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m1_t Sleef_cinz_erfcdx_u15rvvm1nofma(vfloat64m1_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntdx_rvvm1nofma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrdx_rvvm1nofma(int);

#ifndef Sleef_vfloat32m1_t_2_DEFINED
typedef struct {
  vfloat32m1_t x, y;
} Sleef_vfloat32m1_t_2;
#define Sleef_vfloat32m1_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sinfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cosfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_cosfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincosfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_cinz_sincosfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_tanfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_asinfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_asinfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_acosfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_acosfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atanfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_atanfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atan2fx_u35rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_atan2fx_u35rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_logfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_logfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cbrtfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_cbrtfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sinfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cosfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_cosfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincosfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_cinz_sincosfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_tanfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_asinfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_asinfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_acosfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_acosfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atanfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_atanfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atan2fx_u10rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_atan2fx_u10rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_logfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_logfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cbrtfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_cbrtfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_expfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_expfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_powfx_u10rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_powfx_u10rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sinhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_coshfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_coshfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_tanhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinhfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sinhfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_coshfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_coshfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tanhfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_tanhfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fastsinfx_u3500rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fastsinfx_u3500rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fastcosfx_u3500rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fastcosfx_u3500rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fastpowfx_u3500rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fastpowfx_u3500rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_asinhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_asinhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_acoshfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_acoshfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_atanhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_atanhfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp2fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_exp2fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp2fx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_exp2fx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp10fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_exp10fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_exp10fx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_exp10fx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_expm1fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_expm1fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log10fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_log10fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log2fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_log2fx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log2fx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_log2fx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_log1pfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_log1pfx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincospifx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_cinz_sincospifx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_sincospifx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_cinz_sincospifx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sinpifx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sinpifx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cospifx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_cospifx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fmafx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fmafx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sqrtfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sqrtfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sqrtfx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sqrtfx_u05rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_sqrtfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_sqrtfx_u35rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_hypotfx_u05rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_hypotfx_u05rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_hypotfx_u35rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_hypotfx_u35rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fabsfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fabsfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_copysignfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_copysignfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fmaxfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fmaxfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fminfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fminfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fdimfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fdimfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_truncfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_truncfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_floorfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_floorfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_ceilfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_ceilfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_roundfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_roundfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_rintfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_rintfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_nextafterfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_nextafterfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_frfrexpfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_frfrexpfx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_fmodfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_fmodfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_remainderfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_remainderfx_rvvm1nofma(vfloat32m1_t, vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_modffx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m1_t_2 Sleef_cinz_modffx_rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_lgammafx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_lgammafx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_tgammafx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_tgammafx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_erffx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_erffx_u10rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_erfcfx_u15rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m1_t Sleef_cinz_erfcfx_u15rvvm1nofma(vfloat32m1_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntfx_rvvm1nofma(int);
SLEEF_IMPORT SLEEF_CONST int Sleef_cinz_getIntfx_rvvm1nofma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrfx_rvvm1nofma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_cinz_getPtrfx_rvvm1nofma(int);
#endif
#ifdef __riscv_v

#ifndef Sleef_vfloat64m2_t_2_DEFINED
typedef struct {
  vfloat64m2_t x, y;
} Sleef_vfloat64m2_t_2;
#define Sleef_vfloat64m2_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sindx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sindx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cosdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_cosdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincosdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_finz_sincosdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tandx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_tandx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_asindx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_asindx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_acosdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_acosdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atandx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_atandx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atan2dx_u35rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_atan2dx_u35rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_logdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_logdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cbrtdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_cbrtdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sindx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sindx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cosdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_cosdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincosdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_finz_sincosdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tandx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_tandx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_asindx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_asindx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_acosdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_acosdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atandx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_atandx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atan2dx_u10rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_atan2dx_u10rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_logdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_logdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cbrtdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_cbrtdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_expdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_expdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_powdx_u10rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_powdx_u10rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sinhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sinhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_coshdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_coshdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tanhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_tanhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sinhdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sinhdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_coshdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_coshdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tanhdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_tanhdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fastsindx_u3500rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fastsindx_u3500rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fastcosdx_u3500rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fastcosdx_u3500rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fastpowdx_u3500rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fastpowdx_u3500rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_asinhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_asinhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_acoshdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_acoshdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atanhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_atanhdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp2dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_exp2dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp2dx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_exp2dx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp10dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_exp10dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp10dx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_exp10dx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_expm1dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_expm1dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log10dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_log10dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log2dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_log2dx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log2dx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_log2dx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log1pdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_log1pdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincospidx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_finz_sincospidx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincospidx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_finz_sincospidx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sinpidx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sinpidx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cospidx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_cospidx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_ldexpdx_rvvm2(vfloat64m2_t, vint32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_ldexpdx_rvvm2(vfloat64m2_t, vint32m1_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_ilogbdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_finz_ilogbdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmadx_rvvm2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fmadx_rvvm2(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sqrtdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sqrtdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sqrtdx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sqrtdx_u05rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sqrtdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_sqrtdx_u35rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_hypotdx_u05rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_hypotdx_u05rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_hypotdx_u35rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_hypotdx_u35rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fabsdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fabsdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_copysigndx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_copysigndx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmaxdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fmaxdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmindx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fmindx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fdimdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fdimdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_truncdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_truncdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_floordx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_floordx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_ceildx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_ceildx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_rounddx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_rounddx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_rintdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_rintdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_nextafterdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_nextafterdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_frfrexpdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_frfrexpdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_expfrexpdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_finz_expfrexpdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmoddx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_fmoddx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_remainderdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_remainderdx_rvvm2(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_modfdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_finz_modfdx_rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_lgammadx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_lgammadx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tgammadx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_tgammadx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_erfdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_erfdx_u10rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_erfcdx_u15rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_finz_erfcdx_u15rvvm2(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntdx_rvvm2(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrdx_rvvm2(int);

#ifndef Sleef_vfloat32m2_t_2_DEFINED
typedef struct {
  vfloat32m2_t x, y;
} Sleef_vfloat32m2_t_2;
#define Sleef_vfloat32m2_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sinfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cosfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_cosfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincosfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_finz_sincosfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_tanfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_asinfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_asinfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_acosfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_acosfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atanfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_atanfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atan2fx_u35rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_atan2fx_u35rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_logfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_logfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cbrtfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_cbrtfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sinfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cosfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_cosfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincosfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_finz_sincosfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_tanfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_asinfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_asinfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_acosfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_acosfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atanfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_atanfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atan2fx_u10rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_atan2fx_u10rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_logfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_logfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cbrtfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_cbrtfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_expfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_expfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_powfx_u10rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_powfx_u10rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sinhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_coshfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_coshfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_tanhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinhfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sinhfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_coshfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_coshfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanhfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_tanhfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fastsinfx_u3500rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fastsinfx_u3500rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fastcosfx_u3500rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fastcosfx_u3500rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fastpowfx_u3500rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fastpowfx_u3500rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_asinhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_asinhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_acoshfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_acoshfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atanhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_atanhfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp2fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_exp2fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp2fx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_exp2fx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp10fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_exp10fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp10fx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_exp10fx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_expm1fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_expm1fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log10fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_log10fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log2fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_log2fx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log2fx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_log2fx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log1pfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_log1pfx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincospifx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_finz_sincospifx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincospifx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_finz_sincospifx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinpifx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sinpifx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cospifx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_cospifx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fmafx_rvvm2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fmafx_rvvm2(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sqrtfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sqrtfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sqrtfx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sqrtfx_u05rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sqrtfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_sqrtfx_u35rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_hypotfx_u05rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_hypotfx_u05rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_hypotfx_u35rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_hypotfx_u35rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fabsfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fabsfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_copysignfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_copysignfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fmaxfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fmaxfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fminfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fminfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fdimfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fdimfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_truncfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_truncfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_floorfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_floorfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_ceilfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_ceilfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_roundfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_roundfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_rintfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_rintfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_nextafterfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_nextafterfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_frfrexpfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_frfrexpfx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fmodfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_fmodfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_remainderfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_remainderfx_rvvm2(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_modffx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_finz_modffx_rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_lgammafx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_lgammafx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tgammafx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_tgammafx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_erffx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_erffx_u10rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_erfcfx_u15rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_finz_erfcfx_u15rvvm2(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntfx_rvvm2(int);
SLEEF_IMPORT SLEEF_CONST int Sleef_finz_getIntfx_rvvm2(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrfx_rvvm2(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_finz_getPtrfx_rvvm2(int);
#endif
#ifdef __riscv_v

#ifndef Sleef_vfloat64m2_t_2_DEFINED
typedef struct {
  vfloat64m2_t x, y;
} Sleef_vfloat64m2_t_2;
#define Sleef_vfloat64m2_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sindx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sindx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cosdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_cosdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincosdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_cinz_sincosdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tandx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_tandx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_asindx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_asindx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_acosdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_acosdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atandx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_atandx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atan2dx_u35rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_atan2dx_u35rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_logdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_logdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cbrtdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_cbrtdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sindx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sindx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cosdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_cosdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincosdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_cinz_sincosdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tandx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_tandx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_asindx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_asindx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_acosdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_acosdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atandx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_atandx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atan2dx_u10rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_atan2dx_u10rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_logdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_logdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cbrtdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_cbrtdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_expdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_expdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_powdx_u10rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_powdx_u10rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sinhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sinhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_coshdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_coshdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tanhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_tanhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sinhdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sinhdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_coshdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_coshdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tanhdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_tanhdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fastsindx_u3500rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fastsindx_u3500rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fastcosdx_u3500rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fastcosdx_u3500rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fastpowdx_u3500rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fastpowdx_u3500rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_asinhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_asinhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_acoshdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_acoshdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_atanhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_atanhdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp2dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_exp2dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp2dx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_exp2dx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp10dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_exp10dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_exp10dx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_exp10dx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_expm1dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_expm1dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log10dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_log10dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log2dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_log2dx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log2dx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_log2dx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_log1pdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_log1pdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincospidx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_cinz_sincospidx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_sincospidx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_cinz_sincospidx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sinpidx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sinpidx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cospidx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_cospidx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_ldexpdx_rvvm2nofma(vfloat64m2_t, vint32m1_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_ldexpdx_rvvm2nofma(vfloat64m2_t, vint32m1_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_ilogbdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_cinz_ilogbdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmadx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fmadx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sqrtdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sqrtdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sqrtdx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sqrtdx_u05rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_sqrtdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_sqrtdx_u35rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_hypotdx_u05rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_hypotdx_u05rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_hypotdx_u35rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_hypotdx_u35rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fabsdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fabsdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_copysigndx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_copysigndx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmaxdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fmaxdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmindx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fmindx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fdimdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fdimdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_truncdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_truncdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_floordx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_floordx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_ceildx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_ceildx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_rounddx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_rounddx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_rintdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_rintdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_nextafterdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_nextafterdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_frfrexpdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_frfrexpdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_expfrexpdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vint32m1_t Sleef_cinz_expfrexpdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_fmoddx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_fmoddx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_remainderdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_remainderdx_rvvm2nofma(vfloat64m2_t, vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_modfdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat64m2_t_2 Sleef_cinz_modfdx_rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_lgammadx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_lgammadx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_tgammadx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_tgammadx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_erfdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_erfdx_u10rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_erfcdx_u15rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat64m2_t Sleef_cinz_erfcdx_u15rvvm2nofma(vfloat64m2_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntdx_rvvm2nofma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrdx_rvvm2nofma(int);

#ifndef Sleef_vfloat32m2_t_2_DEFINED
typedef struct {
  vfloat32m2_t x, y;
} Sleef_vfloat32m2_t_2;
#define Sleef_vfloat32m2_t_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sinfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cosfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_cosfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincosfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_cinz_sincosfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_tanfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_asinfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_asinfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_acosfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_acosfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atanfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_atanfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atan2fx_u35rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_atan2fx_u35rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_logfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_logfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cbrtfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_cbrtfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sinfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cosfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_cosfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincosfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_cinz_sincosfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_tanfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_asinfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_asinfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_acosfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_acosfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atanfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_atanfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atan2fx_u10rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_atan2fx_u10rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_logfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_logfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cbrtfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_cbrtfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_expfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_expfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_powfx_u10rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_powfx_u10rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sinhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_coshfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_coshfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_tanhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinhfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sinhfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_coshfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_coshfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tanhfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_tanhfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fastsinfx_u3500rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fastsinfx_u3500rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fastcosfx_u3500rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fastcosfx_u3500rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fastpowfx_u3500rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fastpowfx_u3500rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_asinhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_asinhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_acoshfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_acoshfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_atanhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_atanhfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp2fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_exp2fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp2fx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_exp2fx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp10fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_exp10fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_exp10fx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_exp10fx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_expm1fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_expm1fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log10fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_log10fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log2fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_log2fx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log2fx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_log2fx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_log1pfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_log1pfx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincospifx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_cinz_sincospifx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_sincospifx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_cinz_sincospifx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sinpifx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sinpifx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cospifx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_cospifx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fmafx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fmafx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sqrtfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sqrtfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sqrtfx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sqrtfx_u05rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_sqrtfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_sqrtfx_u35rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_hypotfx_u05rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_hypotfx_u05rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_hypotfx_u35rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_hypotfx_u35rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fabsfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fabsfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_copysignfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_copysignfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fmaxfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fmaxfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fminfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fminfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fdimfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fdimfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_truncfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_truncfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_floorfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_floorfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_ceilfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_ceilfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_roundfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_roundfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_rintfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_rintfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_nextafterfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_nextafterfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_frfrexpfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_frfrexpfx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_fmodfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_fmodfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_remainderfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_remainderfx_rvvm2nofma(vfloat32m2_t, vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_modffx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST Sleef_vfloat32m2_t_2 Sleef_cinz_modffx_rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_lgammafx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_lgammafx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_tgammafx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_tgammafx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_erffx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_erffx_u10rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_erfcfx_u15rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST vfloat32m2_t Sleef_cinz_erfcfx_u15rvvm2nofma(vfloat32m2_t);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntfx_rvvm2nofma(int);
SLEEF_IMPORT SLEEF_CONST int Sleef_cinz_getIntfx_rvvm2nofma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrfx_rvvm2nofma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_cinz_getPtrfx_rvvm2nofma(int);
#endif
#ifdef __STDC__

#ifndef Sleef_double_2_DEFINED
typedef Sleef_double2 Sleef_double_2;
#define Sleef_double_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST double Sleef_sind1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sind1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cosd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_cosd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincosd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_cinz_sincosd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tand1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_tand1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_asind1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_asind1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_acosd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_acosd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atand1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_atand1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atan2d1_u35purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_atan2d1_u35purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_logd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_logd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cbrtd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_cbrtd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sind1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sind1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cosd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_cosd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincosd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_cinz_sincosd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tand1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_tand1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_asind1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_asind1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_acosd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_acosd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atand1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_atand1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atan2d1_u10purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_atan2d1_u10purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_logd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_logd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cbrtd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_cbrtd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_expd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_expd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_powd1_u10purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_powd1_u10purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sinhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sinhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_coshd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_coshd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tanhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_tanhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sinhd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sinhd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_coshd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_coshd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tanhd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_tanhd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fastsind1_u3500purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fastsind1_u3500purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fastcosd1_u3500purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fastcosd1_u3500purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fastpowd1_u3500purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fastpowd1_u3500purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_asinhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_asinhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_acoshd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_acoshd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atanhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_atanhd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp2d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_exp2d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp2d1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_exp2d1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp10d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_exp10d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp10d1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_exp10d1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_expm1d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_expm1d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log10d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_log10d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log2d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_log2d1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log2d1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_log2d1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log1pd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_log1pd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincospid1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_cinz_sincospid1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincospid1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_cinz_sincospid1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sinpid1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sinpid1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cospid1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_cospid1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_ldexpd1_purec(double, int32_t);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_ldexpd1_purec(double, int32_t);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_ilogbd1_purec(double);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_cinz_ilogbd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmad1_purec(double, double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fmad1_purec(double, double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sqrtd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sqrtd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sqrtd1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sqrtd1_u05purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sqrtd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_sqrtd1_u35purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_hypotd1_u05purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_hypotd1_u05purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_hypotd1_u35purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_hypotd1_u35purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fabsd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fabsd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_copysignd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_copysignd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmaxd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fmaxd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmind1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fmind1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fdimd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fdimd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_truncd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_truncd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_floord1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_floord1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_ceild1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_ceild1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_roundd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_roundd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_rintd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_rintd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_nextafterd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_nextafterd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_frfrexpd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_frfrexpd1_purec(double);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_expfrexpd1_purec(double);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_cinz_expfrexpd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmodd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_fmodd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_remainderd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_remainderd1_purec(double, double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_modfd1_purec(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_cinz_modfd1_purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_lgammad1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_lgammad1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tgammad1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_tgammad1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_erfd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_erfd1_u10purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_erfcd1_u15purec(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cinz_erfcd1_u15purec(double);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntd1_purec(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrd1_purec(int);

#ifndef Sleef_float_2_DEFINED
typedef Sleef_float2 Sleef_float_2;
#define Sleef_float_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST float Sleef_sinf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sinf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cosf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_cosf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincosf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_cinz_sincosf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_tanf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_asinf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_asinf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_acosf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_acosf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atanf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_atanf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atan2f1_u35purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_atan2f1_u35purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_logf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_logf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cbrtf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_cbrtf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sinf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cosf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_cosf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincosf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_cinz_sincosf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_tanf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_asinf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_asinf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_acosf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_acosf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atanf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_atanf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atan2f1_u10purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_atan2f1_u10purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_logf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_logf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cbrtf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_cbrtf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_expf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_expf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_powf1_u10purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_powf1_u10purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sinhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_coshf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_coshf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_tanhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinhf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sinhf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_coshf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_coshf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanhf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_tanhf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fastsinf1_u3500purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fastsinf1_u3500purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fastcosf1_u3500purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fastcosf1_u3500purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fastpowf1_u3500purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fastpowf1_u3500purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_asinhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_asinhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_acoshf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_acoshf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atanhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_atanhf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp2f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_exp2f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp2f1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_exp2f1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp10f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_exp10f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp10f1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_exp10f1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_expm1f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_expm1f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log10f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_log10f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log2f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_log2f1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log2f1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_log2f1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log1pf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_log1pf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincospif1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_cinz_sincospif1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincospif1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_cinz_sincospif1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinpif1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sinpif1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cospif1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_cospif1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fmaf1_purec(float, float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fmaf1_purec(float, float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sqrtf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sqrtf1_u05purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_sqrtf1_u35purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_hypotf1_u05purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_hypotf1_u05purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_hypotf1_u35purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_hypotf1_u35purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fabsf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fabsf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_copysignf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_copysignf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fmaxf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fmaxf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fminf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fminf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fdimf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fdimf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_truncf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_truncf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_floorf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_floorf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_ceilf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_ceilf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_roundf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_roundf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_rintf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_rintf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_nextafterf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_nextafterf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_frfrexpf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_frfrexpf1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fmodf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_fmodf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_remainderf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_remainderf1_purec(float, float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_modff1_purec(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_cinz_modff1_purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_lgammaf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_lgammaf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tgammaf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_tgammaf1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_erff1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_erff1_u10purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_erfcf1_u15purec(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cinz_erfcf1_u15purec(float);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntf1_purec(int);
SLEEF_IMPORT SLEEF_CONST int Sleef_cinz_getIntf1_purec(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrf1_purec(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_cinz_getPtrf1_purec(int);
#endif
#ifdef __STDC__

#ifndef Sleef_double_2_DEFINED
typedef Sleef_double2 Sleef_double_2;
#define Sleef_double_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST double Sleef_sind1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sind1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cosd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_cosd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincosd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_finz_sincosd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tand1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_tand1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_asind1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_asind1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_acosd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_acosd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atand1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_atand1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atan2d1_u35purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_atan2d1_u35purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_logd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_logd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cbrtd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_cbrtd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sind1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sind1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cosd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_cosd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincosd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_finz_sincosd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tand1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_tand1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_asind1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_asind1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_acosd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_acosd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atand1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_atand1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atan2d1_u10purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_atan2d1_u10purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_logd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_logd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cbrtd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_cbrtd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_expd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_expd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_powd1_u10purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_powd1_u10purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sinhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sinhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_coshd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_coshd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tanhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_tanhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sinhd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sinhd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_coshd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_coshd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tanhd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_tanhd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fastsind1_u3500purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fastsind1_u3500purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fastcosd1_u3500purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fastcosd1_u3500purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fastpowd1_u3500purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fastpowd1_u3500purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_asinhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_asinhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_acoshd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_acoshd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_atanhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_atanhd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp2d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_exp2d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp2d1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_exp2d1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp10d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_exp10d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_exp10d1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_exp10d1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_expm1d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_expm1d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log10d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_log10d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log2d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_log2d1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log2d1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_log2d1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_log1pd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_log1pd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincospid1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_finz_sincospid1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_sincospid1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_finz_sincospid1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sinpid1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sinpid1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_cospid1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_cospid1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_ldexpd1_purecfma(double, int32_t);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_ldexpd1_purecfma(double, int32_t);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_ilogbd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_finz_ilogbd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmad1_purecfma(double, double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fmad1_purecfma(double, double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sqrtd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sqrtd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sqrtd1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sqrtd1_u05purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_sqrtd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_sqrtd1_u35purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_hypotd1_u05purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_hypotd1_u05purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_hypotd1_u35purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_hypotd1_u35purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fabsd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fabsd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_copysignd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_copysignd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmaxd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fmaxd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmind1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fmind1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fdimd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fdimd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_truncd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_truncd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_floord1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_floord1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_ceild1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_ceild1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_roundd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_roundd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_rintd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_rintd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_nextafterd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_nextafterd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_frfrexpd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_frfrexpd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_expfrexpd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST int32_t Sleef_finz_expfrexpd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_fmodd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_fmodd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_remainderd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_remainderd1_purecfma(double, double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_modfd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST Sleef_double_2 Sleef_finz_modfd1_purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_lgammad1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_lgammad1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_tgammad1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_tgammad1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_erfd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_erfd1_u10purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_erfcd1_u15purecfma(double);
SLEEF_IMPORT SLEEF_CONST double Sleef_finz_erfcd1_u15purecfma(double);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntd1_purecfma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrd1_purecfma(int);

#ifndef Sleef_float_2_DEFINED
typedef Sleef_float2 Sleef_float_2;
#define Sleef_float_2_DEFINED
#endif

SLEEF_IMPORT SLEEF_CONST float Sleef_sinf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sinf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cosf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_cosf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincosf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_finz_sincosf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_tanf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_asinf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_asinf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_acosf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_acosf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atanf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_atanf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atan2f1_u35purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_atan2f1_u35purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_logf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_logf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cbrtf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_cbrtf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sinf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cosf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_cosf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincosf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_finz_sincosf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_tanf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_asinf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_asinf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_acosf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_acosf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atanf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_atanf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atan2f1_u10purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_atan2f1_u10purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_logf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_logf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cbrtf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_cbrtf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_expf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_expf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_powf1_u10purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_powf1_u10purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sinhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_coshf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_coshf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_tanhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinhf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sinhf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_coshf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_coshf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tanhf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_tanhf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fastsinf1_u3500purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fastsinf1_u3500purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fastcosf1_u3500purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fastcosf1_u3500purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fastpowf1_u3500purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fastpowf1_u3500purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_asinhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_asinhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_acoshf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_acoshf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_atanhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_atanhf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp2f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_exp2f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp2f1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_exp2f1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp10f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_exp10f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_exp10f1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_exp10f1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_expm1f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_expm1f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log10f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_log10f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log2f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_log2f1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log2f1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_log2f1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_log1pf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_log1pf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincospif1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_finz_sincospif1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_sincospif1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_finz_sincospif1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sinpif1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sinpif1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_cospif1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_cospif1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fmaf1_purecfma(float, float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fmaf1_purecfma(float, float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sqrtf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sqrtf1_u05purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_sqrtf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_sqrtf1_u35purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_hypotf1_u05purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_hypotf1_u05purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_hypotf1_u35purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_hypotf1_u35purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fabsf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fabsf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_copysignf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_copysignf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fmaxf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fmaxf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fminf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fminf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fdimf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fdimf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_truncf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_truncf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_floorf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_floorf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_ceilf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_ceilf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_roundf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_roundf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_rintf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_rintf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_nextafterf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_nextafterf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_frfrexpf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_frfrexpf1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_fmodf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_fmodf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_remainderf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_remainderf1_purecfma(float, float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_modff1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST Sleef_float_2 Sleef_finz_modff1_purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_lgammaf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_lgammaf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_tgammaf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_tgammaf1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_erff1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_erff1_u10purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_erfcf1_u15purecfma(float);
SLEEF_IMPORT SLEEF_CONST float Sleef_finz_erfcf1_u15purecfma(float);
SLEEF_IMPORT SLEEF_CONST int Sleef_getIntf1_purecfma(int);
SLEEF_IMPORT SLEEF_CONST int Sleef_finz_getIntf1_purecfma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_getPtrf1_purecfma(int);
SLEEF_IMPORT SLEEF_CONST void *Sleef_finz_getPtrf1_purecfma(int);
#endif

//

#ifdef __cplusplus
} // extern "C"
#endif

#endif // #ifndef __SLEEF_H__
